==> survex_1.0.7.tar.gz: survex-1.0.7/src/aventreectrl.h <==
//
//  aventreectrl.h
//
//  Tree control used for the survey tree.
//
//  Copyright (C) 2001, Mark R. Shinwell.
//  Copyright (C) 2002, Olly Betts
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//

#ifndef aventreectrl_h
#define aventreectrl_h

#include "wx.h"

class MainFrm;

class AvenTreeCtrl : public wxTreeCtrl {
    MainFrm* m_Parent;
    bool m_Enabled;
    wxTreeItemId m_LastItem;
    wxColour m_BackgroundColour;
    bool m_SelValid;

public:
    AvenTreeCtrl(MainFrm* parent, wxWindow* window_parent);

    void SetEnabled(bool enabled = true);
    void UnselectAll();

    void OnMouseMove(wxMouseEvent& event);
    void OnSelChanged(wxTreeEvent& event);
    void OnKeyPress(wxKeyEvent &e);

    bool GetSelectionData(wxTreeItemData**);

    void DeleteAllItems();

private:
    DECLARE_EVENT_TABLE()
};

#endif

==> survex_1.0.34.tar.gz: survex-1.0.34/src/aventreectrl.h <==
//
//  aventreectrl.h
//
//  Tree control used for the survey tree.
//
//  Copyright (C) 2001, Mark R. Shinwell.
//  Copyright (C) 2002, Olly Betts
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//

#ifndef aventreectrl_h
#define aventreectrl_h

#include "wx.h"

class MainFrm;
class LabelInfo;

class TreeData : public wxTreeItemData {
    const LabelInfo* m_Label;

public:
    TreeData(const LabelInfo* label) : m_Label(label) {}
    const LabelInfo* GetLabel() const { return m_Label; }
    bool IsStation() const { return m_Label != NULL; }
};

class AvenTreeCtrl : public wxTreeCtrl {
    MainFrm* m_Parent;
    bool m_Enabled;
    wxTreeItemId m_LastItem;
    wxColour m_BackgroundColour;
    bool m_SelValid;

public:
    AvenTreeCtrl(MainFrm* parent, wxWindow* window_parent);

    void SetEnabled(bool enabled = true);
    void UnselectAll();

    void OnMouseMove(wxMouseEvent& event);
    void OnSelChanged(wxTreeEvent& event);
    void OnKeyPress(wxKeyEvent &e);

    bool GetSelectionData(wxTreeItemData**);

    void DeleteAllItems();

private:
    DECLARE_EVENT_TABLE()
};

#endif
